package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.MqttSensorThreshold;

/**
 * 传感器阈值配置Service接口
 * 
 * @author shzg
 * @date 2026-04-01
 */
public interface IMqttSensorThresholdService 
{
    /**
     * 查询传感器阈值配置
     * 
     * @param id 传感器阈值配置主键
     * @return 传感器阈值配置
     */
    public MqttSensorThreshold selectMqttSensorThresholdById(Long id);

    /**
     * 查询传感器阈值配置列表
     * 
     * @param mqttSensorThreshold 传感器阈值配置
     * @return 传感器阈值配置集合
     */
    public List<MqttSensorThreshold> selectMqttSensorThresholdList(MqttSensorThreshold mqttSensorThreshold);

    /**
     * 新增传感器阈值配置
     * 
     * @param mqttSensorThreshold 传感器阈值配置
     * @return 结果
     */
    public int insertMqttSensorThreshold(MqttSensorThreshold mqttSensorThreshold);

    /**
     * 修改传感器阈值配置
     * 
     * @param mqttSensorThreshold 传感器阈值配置
     * @return 结果
     */
    public int updateMqttSensorThreshold(MqttSensorThreshold mqttSensorThreshold);

    /**
     * 批量删除传感器阈值配置
     * 
     * @param ids 需要删除的传感器阈值配置主键集合
     * @return 结果
     */
    public int deleteMqttSensorThresholdByIds(Long[] ids);

    /**
     * 删除传感器阈值配置信息
     * 
     * @param id 传感器阈值配置主键
     * @return 结果
     */
    public int deleteMqttSensorThresholdById(Long id);


    /**
     * 根据设备ID和部门ID获取阈值
     * @param id
     * @param deptId
     * @param battery
     * @return
     */
    MqttSensorThreshold getThreshold(Long id, Long deptId, String battery);

}
