package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttSensorThreshold;
import com.shzg.project.worn.service.IMqttSensorThresholdService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 传感器阈值配置Controller
 * 
 * @author shzg
 * @date 2026-04-01
 */
@RestController
@RequestMapping("/worn/threshold")
public class MqttSensorThresholdController extends BaseController
{
    @Autowired
    private IMqttSensorThresholdService mqttSensorThresholdService;

    /**
     * 查询传感器阈值配置列表
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttSensorThreshold mqttSensorThreshold)
    {
        startPage();
        List<MqttSensorThreshold> list = mqttSensorThresholdService.selectMqttSensorThresholdList(mqttSensorThreshold);
        return getDataTable(list);
    }

    /**
     * 导出传感器阈值配置列表
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:export')")
    @Log(title = "传感器阈值配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttSensorThreshold mqttSensorThreshold)
    {
        List<MqttSensorThreshold> list = mqttSensorThresholdService.selectMqttSensorThresholdList(mqttSensorThreshold);
        ExcelUtil<MqttSensorThreshold> util = new ExcelUtil<MqttSensorThreshold>(MqttSensorThreshold.class);
        util.exportExcel(response, list, "传感器阈值配置数据");
    }

    /**
     * 获取传感器阈值配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttSensorThresholdService.selectMqttSensorThresholdById(id));
    }

    /**
     * 新增传感器阈值配置
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:add')")
    @Log(title = "传感器阈值配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttSensorThreshold mqttSensorThreshold)
    {
        return toAjax(mqttSensorThresholdService.insertMqttSensorThreshold(mqttSensorThreshold));
    }

    /**
     * 修改传感器阈值配置
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:edit')")
    @Log(title = "传感器阈值配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttSensorThreshold mqttSensorThreshold)
    {
        return toAjax(mqttSensorThresholdService.updateMqttSensorThreshold(mqttSensorThreshold));
    }

    /**
     * 删除传感器阈值配置
     */
    @PreAuthorize("@ss.hasPermi('worn:threshold:remove')")
    @Log(title = "传感器阈值配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttSensorThresholdService.deleteMqttSensorThresholdByIds(ids));
    }
}
